@@ -242,4 +242,40 @@ sub get_set {
   return $Sets{$key};
 }
 
-1;
\ No newline at end of file
+1;
+
+
+__END__
+
+=head1 NAME
+
+RapidApp::TableSpec::Column::Profile - TableSpec Column Profile Definitions
+
+=head1 DESCRIPTION
+
+This class conatins the TableSpec column profile defintions. This class is used
+internally and should not be called directly. See L<RapidApp::Manual::TableSpec> 
+for more info
+
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<RapidApp::Manual::TableSpec>
+
+=back
+
+=head1 AUTHOR
+
+Henry Van Styn <vanstyn@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by IntelliTree Solutions llc.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
